'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _only = require('only');

var _only2 = _interopRequireDefault(_only);

var _util = require('./util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var app = require('express')(),
    items = require('js-yaml').safeLoad(_fs2.default.readFileSync(process.env.ITEMS_PATH || 'items.yaml')),
    charge = require('lightning-charge-client')(process.env.CHARGE_URL, process.env.CHARGE_TOKEN);

Object.keys(items).filter(function (k) {
  return !items[k].title;
}).forEach(function (k) {
  return items[k].title = k;
});

app.set('port', process.env.PORT || 9116);
app.set('host', process.env.HOST || 'localhost');
app.set('title', process.env.TITLE || 'Lightning Nano POS');
app.set('currency', process.env.CURRENCY || 'BTC');
app.set('theme', process.env.THEME || 'yeti');
app.set('views', _path2.default.join(__dirname, '..', 'views'));
app.set('trust proxy', process.env.PROXIED || 'loopback');

app.set('custom_amount', !process.env.NO_CUSTOM);
app.set('show_bolt11', !!process.env.SHOW_BOLT11);

app.locals.formatFiat = (0, _util.fiatFormatter)(app.settings.currency);

app.use(require('cookie-parser')());
app.use(require('body-parser').json());
app.use(require('body-parser').urlencoded({ extended: true }));

app.use(require('morgan')('dev'));
app.use(require('csurf')({ cookie: true }));

app.get('/', function (req, res) {
  return res.render('index.pug', { req: req, items: items });
});

app.use('/bootswatch', require('express').static(_path2.default.resolve(require.resolve('bootswatch/package'), '..', 'dist')));

// use pre-compiled browserify bundle when available, or live-compile for dev
var compiledBundle = _path2.default.join(__dirname, 'client.bundle.min.js');
if (_fs2.default.existsSync(compiledBundle)) app.get('/script.js', function (req, res) {
  return res.sendFile(compiledBundle);
});else app.get('/script.js', require('browserify-middleware')(require.resolve('./client')));

app.post('/invoice', (0, _util.pwrap)(function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(req, res) {
    var item, metadata, inv;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            item = req.body.item ? items[req.body.item] : app.enabled('custom_amount') ? { price: req.body.amount } : null;

            if (item) {
              _context.next = 3;
              break;
            }

            return _context.abrupt('return', res.sendStatus(404));

          case 3:
            metadata = { source: 'nanopos', item: req.body.item };


            if (item.metadata) Object.assign(metadata, item.metadata);

            _context.next = 7;
            return charge.invoice({
              amount: item.price,
              currency: item.price ? app.settings.currency : null,
              description: '' + app.settings.title + (item.title ? ': ' + item.title : ''),
              expiry: 599,
              metadata: metadata
            });

          case 7:
            inv = _context.sent;

            res.send((0, _only2.default)(inv, 'id payreq msatoshi quoted_currency quoted_amount expires_at'));

          case 9:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  }));

  return function (_x, _x2) {
    return _ref.apply(this, arguments);
  };
}()));

app.get('/invoice/:invoice/wait', (0, _util.pwrap)(function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(req, res) {
    var paid;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return charge.wait(req.params.invoice, 100);

          case 2:
            paid = _context2.sent;

            res.sendStatus(paid === null ? 402 : paid ? 204 : 410);

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, undefined);
  }));

  return function (_x3, _x4) {
    return _ref2.apply(this, arguments);
  };
}()));

app.listen(app.settings.port, app.settings.host, function (_) {
  return console.log('HTTP server running on ' + app.settings.host + ':' + app.settings.port);
});